# flashinfer_bench.data.Workload

```{eval-rst}
.. currentmodule:: flashinfer_bench.data

.. autopydantic_model:: Workload

.. autopydantic_model:: RandomInput

.. autopydantic_model:: ScalarInput

.. autopydantic_model:: SafetensorsInput

.. autodata:: InputSpec

   Union type representing all possible input specification types.
```
